Secreted protein signaling velocity for single-cell ST
Source:R/downstream.R
SecAct.signaling.velocity.scST.RdCalculate the signaling velocity of secreted proteins based on their activities.
Usage
SecAct.signaling.velocity.scST(
SpaCET_obj,
sender,
secretedProtein,
receiver,
cellType_meta,
scale.factor = 1e+05,
CustomizedAreaCoordinates = NULL,
radius = 20,
colors_cellType = NULL
)Arguments
- SpaCET_obj
A SpaCET object.
- sender
Sender cell types.
- secretedProtein
Secreted proteins.
- receiver
Receiver cell types.
- cellType_meta
Column name in meta data that includes cell-type annotations.
- scale.factor
Sets the scale factor for spot-level normalization.
- CustomizedAreaCoordinates
Optional coordinates for customized area c(x.left, x.right, y.bottom, y.top).
- radius
Radius cut off (unit: um).
- colors_cellType
Named vector of colors for cell types.
Details
The velocity direction starts from the source cell producing a secreted protein and moves to sink cells receiving the secreted protein signal. The velocity magnitude represents the product between the secreted protein-coding gene expression at source cells and signaling activities at sink cells.